@@ -3,7 +3,6 @@
 """Module containing logic for command based detectors."""
 
 from .base import IPDetector
-from ..common.six import PY3
 
 
 class IPDetector_Command(IPDetector):
@@ -34,10 +33,7 @@ class IPDetector_Command(IPDetector):
 
     def detect(self):
         """Detect and return the IP address."""
-        if PY3:  # py23
-            import subprocess  # noqa: S404 @UnresolvedImport pylint: disable=import-error
-        else:
-            import commands as subprocess  # @UnresolvedImport pylint: disable=import-error
+        import subprocess  # noqa: S404 @UnresolvedImport pylint: disable=import-error
         try:
             theip = subprocess.getoutput(self.opts_command)  # noqa: S605
         except Exception:
